@@ -2,4 +2,4 @@ from .exceptions import AccessPolicyException
 from .access_policy import AccessPolicy
 from .access_view_set_mixin import AccessViewSetMixin
 from .field_access_mixin import FieldAccessMixin
-from .fields import PermittedPkRelatedField
+from .fields import PermittedPkRelatedField, PermittedSlugRelatedField
